@@ -1,7 +1,7 @@
 from vade_api_src.vade_enums import *
 from datetime import datetime
 from dateutil import parser
-
+from enum import Enum
 
 class GeoPoint:
     lat: float
@@ -84,6 +84,98 @@ class DefaultGeoPoints:
     seattle = GeoPoint(47.59325962698753, -122.32440174831653)
 
 
+class VadeVehicleType(Enum):
+    SUV = "SUV"
+    SEDAN = "sedan"
+    MINIVAN = 'minivan'
+    MPV = "MPV"
+    LARGE_TRUCK = "large truck"
+    LARGE_BUS = "large-sized bus"
+    LIGHT_PASSENGER_VEHICLE = "light passenger vehicle"
+    PICKUP_TRUCK = "pickup truck"
+
+    @staticmethod
+    def from_str(str_val: str):
+        try:
+            return VadeVehicleType[str_val]
+        except Exception as e:
+            return None
+
+
+class TypeOption:
+
+    type: VadeVehicleType
+    confidence: float
+
+    @staticmethod
+    def from_json(j: dict):
+        try:
+            new = TypeOption()
+            new.type = VadeVehicleType.from_str(j['type'])
+            new.confidence = j['confidence']
+            return new
+        except:
+            return None
+
+    def to_json(self):
+        ret_val = {"type": self.type.value, "confidence": self.confidence}
+        return ret_val
+
+class ColorOption:
+
+    color: str
+    weight: float
+
+    @staticmethod
+    def from_json(j: dict):
+        try:
+            new = ColorOption()
+            new.color = j['color']
+            new.weight = j['weight']
+            return new
+        except:
+            return None
+
+    def to_json(self):
+        ret_val = {"color": self.color, "weight": self.weight}
+        return ret_val
+
+
+class VadeSpotVehicleDetails:
+    color_options: [ColorOption] = []
+    vehicle_type_options: [TypeOption] = []
+
+    @staticmethod
+    def from_json(j: dict):
+        try:
+            new = VadeSpotVehicleDetails()
+            try:
+                color_ops_raw = j["color"]
+                for option in color_ops_raw:
+                    new_color = ColorOption.from_json(option)
+                    if new_color:
+                        new.color_options.append(new_color)
+                new.vehicle_type_options.sort(key=lambda opt: opt.weight, reverse=True)
+            except:
+                new.color_options = []
+
+            try:
+                type_ops_raw = j["typeOptions"]
+                for option in type_ops_raw:
+                    new_type = TypeOption.from_json(option)
+                    if new_type:
+                        new.vehicle_type_options.append(new_type)
+                new.vehicle_type_options.sort(key=lambda opt: opt.confidence, reverse=True)
+            except:
+                new.color_options = []
+            return new
+        except:
+            return None
+
+    def to_json(self):
+        ret_val = {"typeOptions": self.vehicle_type_options, "color": self.color_options}
+        return ret_val
+
 
 class VadeSpotPoint:
     x: int
@@ -122,6 +214,7 @@ class VadeSpotRealtime:
     raw_score: float = None
     last_updated: datetime
     occupied: bool = None
+    vehicle_details: VadeSpotVehicleDetails = None
 
     @staticmethod
     def from_json(j: dict):
@@ -139,9 +232,15 @@ class VadeSpotRealtime:
             new_spot.raw_score = j.get("rawScore", 0.0)
             new_spot.occupied = j.get("occupied", None)
             updated_str = j.get("timeUpdated", None)
+            if not updated_str:
+                updated_str = j.get("lastUpdated", None)
             if updated_str:
                 new_spot.last_updated = parser.parse(updated_str)
                 new_spot.occupied = j["occupied"]
+            vehicle_options_raw = j.get("vehicleDetails", None)
+            if vehicle_options_raw:
+                new_options = VadeSpotVehicleDetails.from_json(vehicle_options_raw)
+                new_spot.vehicle_details = new_options
             return new_spot
         except Exception as e:
             print("failed to create spot from json: {}".format(str(e)))
